ievo должна быть таким, что бы она могла сама себя развивать, становил в проект, и допустим она сразу срашивает, ты хочешь код рефакторинг под       
  пятница, и если да, то она устанвливает gihub workflow c app refactoring, но так же этот апп можно запустить через команд лайн, что бы катать его локально и     
  смотреть результаты, пока что оринетируемся только на гитхаб и его ворклофус + локальный запусуск, так как локально будет дешевле, или допустим секьбрити скан   
  найтли, вот такие интересные сценарии, и обязаткльно нужен тестер через inspect ai не знаю какой, может это в еве нужно и оставить, провреять улучшения ievo       
  имменно по промптингу, и  часто agents пишут тесты либо мокнутые наглухо либо подгоняют тесты под криыве алгоритмы и нужна какая то оценка уверенности


плагины для ide, т.е. сама ievo vscode, pycharm, unity(это очень инетерсно)
с юнити сейчас прям беда

и давай улучшим структуру ресерча если можно reasarch/finings/comparing A va B and why/conslusion/final descision and why  


сереч идеи(app?) но пока нет app, еще один скилл, агент ли флоу, анализ рынка, кто уже делал и как, есть ли поенсорс что бы не изобретать завово, какие есть решения и ресечр по каждому решению

